Rizikos vertinimas su OiRA | OiRA

Temos

# Rizikos vertinimas su OiRA

## Pradėti naują sesiją

Norėdami pradėti naują rizikos vertinimą, spustelėkite nuorodą „Pradėti naują sesiją“.

## Rizikos vertinimo pradžia

Pradėtą rizikos vertinimą visada rasite valdymo skyde po antrašte „Mano rizikos vertinimai“. Čia taip pat galite pradėti naują rizikos vertinimą.

Valdymo skydas

## Rizikos vertinimo etapai

Kiekvieną kartą vertindami riziką pereisite kelis etapus. Jie matomi pagrindiniame meniu kairėje ekrano pusėje:

- Pasirengimas
- Dalyvavimas
- Nustatymas + vertinimas
- Veiksmų planas
- Ataskaita
- Būsena

Priklausomai nuo OiRA partnerių ir (ar) priemonių kūrėjų priimtų sprendimų, kiekvienos priemonės struktūra gali šiek tiek skirtis. Kai kuriose versijose rizikos nustatymo ir vertinimo etapas apima ir veiksmų planą. Tokiu atveju kairėje pusėje pateikiamas toks meniu:

- Pasirengimas
- Dalyvavimas
- Vertinimas
- Ataskaita
- Būsena

## Pasirengimas

„Pasirengimas“ - pirmas žingsnis pradedant kiekvieną sesiją (arba pradedant naudoti priemonę). Parinkę rizikos vertinimo pavadinimą, vėliau galėsite lengviau surasti su šia priemone atliktus atskirus rizikos vertinimus.

Daugiau informacijos apie pasirinktą priemonę ir su jos kūrimu susijusius subjektus pateikiama spustelėjus nuorodą „Daugiau informacijos apie šią priemonę…“.

Spustelėjus mygtuką „Pradėti“, gali būti užduota papildomų klausimų, priklausomai nuo naudojamos priemonės. Šis parengiamasis langas su klausimais apie įmonės profilį rodomas tik tose priemonėse, kurios suteikia tokią galimybę.

Čia galite:

- Pasirinkti arba praleisti situaciją (-as) priklausomai nuo to, ar ji (jos) būdinga (-os) jūsų įmonei. Kur tinkama, pasirinkite „taip“.
- Išvardykite kelis įmonės padalinius, filialus ar parduotuves ir t. t. Susiję rizikos veiksniai bus pakartoti prie kiekvieno įrašo.

„Profilio“ langas „Pasirengimo“ etape

Pasirengimo etapas yra labai svarbus, nes juo tiksliai apibrėžiama verslo rūšis ir susiję rizikos veiksniai, su kuriais susiduria jūsų įmonė. Spustelėję mygtuką „Išsaugoti ir tęsti“, pateksite į kitą etapą „Dalyvavimas“.

Pastaba: Daugelyje priemonių nėra klausimų apie įmonės profilį, nes ši funkcija nenaudojama priemonei nukreipti. Tokiu atveju šis langas automatiškai praleidžiamas.

## Dalyvavimas

Šiame etape primenama darbuotojų dalyvavimo svarba ir paaiškinama, kaip užtikrinti tinkamą darbuotojų dalyvavimą. Čia galite atsisiųsti arba atsispausdinti rizikos vertinimo turinį, kad galėtumėte juo pasidalyti su savo darbuotojais. Taip užtikrinama, kad darbuotojai galėtų prisidėti prie situacijos darbo vietoje vertinimo.

## Vertinimas

Šiame etape nustatysite jūsų įmonei būdingus pavojus ir problemas.

Pastaba: Priklausomai nuo to, kaip OiRA partneris priemonę sukonfigūravo, šiame lange gali būti veiksmų plano etapas (žr. toliau). Tokiu atveju visas etapas vadinamas „Vertinimu“, o „Veiksmų plane“ aprašyti veiksmai pateikiami prie kiekvienos rizikos rūšies nustatymo ir vertinimo.

Nustatymas ir vertinimas

Ekrano kairėje po parinktimis „Nustatymas + vertinimas“ / „Vertinimas“ galima matyti visas priemonėje esančias temas / modulius. Žiūrima tema būna paryškinta.

### Nustatymas

Dėl kiekvieno rizikos veiksnio turite nuspręsti, ar teiginys apie norimą būklę gali būti taikomas jūsų įmonei. Galite atsakyti taip:

- Taip: jei atsakote „taip“, tolesnių veiksmų imtis neturite, nes įvertinote, kad tokios rizikos nėra.
- Ne: jei atsakote „ne“, turite imtis tolesnių veiksmų. Jūsų bus paprašyta nuspręsti dėl konkrečių priemonių.
- Netaikoma: kai kurie teiginiai apie riziką numato galimybę pasirinkti „netaikoma“, jei rizika neaktuali jūsų įmonei ir (ar) įstaigai.

Po kiekvienu teiginiu paprastai pateikiama daugiau informacijos apie konkrečią riziką:

- Informacija: trumpas aprašymas, kartais kartu su vaizdine medžiaga, kuriame pateikiama daugiau informacijos apie riziką.
- Ištekliai: papildoma informacija apie riziką, pvz., nuorodos į teisinius ir politikos šaltinius. Kartais čia gali būti dokumentai, skirti nuodugnesniam temos nagrinėjimui.
- Pastabos: čia galite pateikti savo pastabas, kurios bus pateiktos jūsų ataskaitoje vertinimo pabaigoje.

Atsakius į teiginį apie riziką ir toliau tęsiant darbą, kairėje pusėje esančiame meniu spalvotu simboliu pažymima, kad meniu atnaujintas ir:

- jūsų atsakymas teigiamas (žalia varnelė)
- jūsų atsakymas neigiamas (raudonas kryželis)
- atsakymas atidėtas (oranžinis klaustukas)

Jei į klausimą neatsakyta, lieka pilkas simbolis.

### Vertinimas

Šiame etape vertinate savo nustatytos rizikos prioritetą.

Rizikos vertinimas

Pastaba: Kai kuriose OiRA priemonėse vertinimas nerodomas. Tai priklauso nuo šalies partnerio / OiRA priemonės kūrėjo įvestų konkrečios OiRA priemonės nustatymų.

Jei nustatėte, kad rizika yra (pažymėta raudonu kryželiu), pasirodys vertinimo skirsnis. Priklausomai nuo kiekvienam rizikos veiksniui nustatyto vertinimo metodo, jūsų bus paprašyta:

Įvertinti prioritetą: didelis, vidutinis ar mažas

Rizikos prioriteto nustatymas

ARBA

- atsakyti į keletą klausimų apie rizikos dažnumą, rimtumą ir tikimybę, kad remiantis jūsų atsakymais būtų galima nustatyti rizikos prioritetą.

Rizikos kintamųjų nustatymas

### Pagal sektorių nustatyti prioritetiniai rizikos veiksniai:

Nacionalinio partnerio ir (ar) konkrečios OiRA priemonės kūrėjų vertinimu, kai kurie rizikos veiksniai laikomi ypač svarbiais. Tokių „prioritetinių rizikos veiksnių“ jums vertinti nereikia - jiems automatiškai nustatoma reikšmė „didelė rizika“.

Prioritetinė rizika

### Individualūs įmonei būdingi rizikos veiksniai

Baigę atsakinėti į visas rizikos temas skiltyje „Atranka + vertinimas“ / „Vertinimas“, prieisite papildomai pasirenkamą temą „Kita rizika“. Spustelėję mygtuką „Pridėti individualius įmonei būdingus rizikos veiksnius“, galėsite susikurti savo įrašus.

Jei jūsų darbo vietoje ir (arba) jūsų įmonėje yra rizikos veiksnių, kurie priemonėje nenumatyti, juos turite pridėti čia. Tokius rizikos veiksnius aiškiai įvardijate ir (arba) apibrėžiate jūs patys.

Individualūs įmonei būdingi rizikos veiksniai.

„Individualių įmonei būdingų rizikos veiksnių“ parinktis veikia labai panašiai kaip ir OiRA priemonėje nustatyti rizikos veiksniai, tik šią riziką turite aprašyti patys. Bent trumpai turėtų būti pristatyta probleminė padėtis. Galima pateikti ir ilgesnį aprašymą. Konkrečiai padėčiai iliustruoti galima įkelti paveikslėlį / nuotrauką.

Kaip ir bet kurios rizikos atveju, turite nurodyti, ar rizika šiuo metu patiriama ar ne. Taip galėsite pažymėti individualius įmonei būdingus rizikos veiksnius, kai juos sėkmingai pašalinsite, tačiau išsaugosite juos rizikos vertinimo istorijoje dokumentacijos tikslais.

Galite pridėti tiek individualių įmonei būdingų rizikos veiksnių, kiek reikia.

Pridėti individualius įmonei būdingus rizikos veiksnius

## Veiksmų planas

Šiame etape nuspręsite, kokius veiksmus norite atlikti, kad nustatyta rizika būtų pašalinta arba sumažinta.

Pastaba: Kaip minėta anksčiau, veiksmų planas pateikiamas kaip atskiras etapas kairėje pusėje esančiame meniu arba prie kiekvieno nustatyto rizikos veiksnio. Pastaruoju atveju meniu matomas etapas vadinamas „Vertinimu“ ir apima tiek teiginius apie riziką, tiek atsakomųjų veiksmų pasirinkimą.

Tai, kokia versija naudojatės jūs, priklauso nuo nacionalinio OiRA partnerio ir (ar) priemonės kūrėjo priimtų sprendimų.

### Integruotas veiksmų planas

Integruotas veiksmų planas

Jei į klausimą atsakėte neigiamai, puslapyje po antrašte „Priemonės“ atsidarys veiksmų plano modulis.

Galite rinktis sistemos siūlomas priemones arba apibrėžti savo priemones.

### Atskiras veiksmų planas

Jei veiksmų planas sudaromas kaip atskiras etapas, nuoroda į jį pateikiama kairėje ekrano pusėje.

Norėdami sudaryti veiksmų planą spustelėkite mygtuką „Sukurti veiksmų planą“.

Veiksmų plano etape ekrano kairėje pusėje esančiame meniu rodoma tik ta rizika, kuri reikalauja tolesnių veiksmų, nes pažymėta, kad kitų rizikos veiksnių nėra.

Kiekvienam rizikos veiksniui, apie kurį vertinimo etape atsakėte „ne“, taip pat visiems prioritetinės rizikos veiksniams (neatsižvelgiant į tai, ar atsakymas apie juos buvo teigiamas ar neigiamas) jūsų bus paprašyta nustatyti priemones.

Į veiksmų planą įtraukta rizika.

Galite rinktis sistemos siūlomas priemones arba nustatyti savas.

#### Pridėti savo priemonę

Papildomos priemonės pridėjimas.

Prevencinei priemonei nustatyti naudokite mygtuką „Pridėti priemonę“. Reikėtų:

- Aprašyti bendrą metodą, kurio bus laikomasi siekiant pašalinti arba sumažinti riziką.
- Galima nurodyti (bet neprivaloma) reikiamą kompetencijos lygį ir (ar) reikalavimus (pvz., čia galite nurodyti, ar šiai rizikai pašalinti reikalingi konkretūs mokymai ar išorės ekspertai)
- Įvesti informaciją apie tai, kas atsakingas už įgyvendinimą.
- Jei taikoma, nustatyti biudžetą.
- Pasirinktinai nustatyti datas, kada pradėsite įgyvendinti priemonę ir kada planuojate ją užbaigti.

Galite pridėti tiek priemonių, kiek reikia.

#### Pridėti standartines priemones

Priklausomai nuo OiRA partnerio ir (ar) priemonės kūrėjo pasirinktų nustatymų, atskiroms rizikoms rūšims galima pasirinkti iš anksto nustatytas priemones. Norėdami pasirinkti vieną ar daugiau iš anksto nustatytą priemonę, spustelėkite mygtuką „Pasirinkti standartines priemones“.

Atsidaro išskleidžiamasis meniu, kuriame pateikiamos visos siūlomos priemonės. Spustelėkite mygtuką „Pridėti“ prie tų priemonių, kurias norite naudoti.

Iš anksto nustatytos priemonės bus išvardytos jūsų veiksmų plane. Veiksmų aprašymo keisti negalite, tačiau kitus laukelius (atsakomybė, biudžetas, datos) jūs galite ir turėtumėte užpildyti patys.

Standartinės priemonės pridėjimas.

Tiek standartines, tiek jūsų nustatytas priemones visada galima ištrinti.

## Ataskaita

Užbaigę veiksmų planą, galite parengti ataskaitą.

Jei norite ataskaitoje palikti komentarą, įrašykite savo tekstą čia ir jį išsaugokite.

Komentuoti ataskaitą

Norėdami sužinoti daugiau apie įvairias ataskaitas ir kaip jomis naudotis, žr. čia.

## Būsena

Nedidelėje diagramoje (esančioje meniu kairėje pusėje) parodyta, kokią pažangą padarėte naudodami šią priemonę.

Būsenos skyriuje apžvelgiama, kiek rizikos veiksnių nustatėte, keliems iš jų nustatytos priemonės ir dėl kelių nesiimta jokių veiksmų.

Būsenos puslapis

Būsenos ekrane matoma, kokia pažanga padaryta kiekviename modulyje. Tai gali padėti įvertinti, kokius rizikos veiksnius vis dar reikia įvertinti ar pasirinkti rizikos valdymo priemones jau nustatytiems rizikos veiksniams.

Scroll to top Load toolbar…
Back

## 3-carrying-out-a-risk-assessment.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More